@@ -166,7 +166,8 @@ Initialize(WMScreen *scr)
 		panel->sndevntP = WMCreatePopUpButton(panel->sndevntF);
 		WMResizeWidget(panel->sndevntP, 196, 20);
 		WMMoveWidget(panel->sndevntP, 8, 16);
-		WMAddPopUpButtonItem(panel->sndevntP, _("WMSound Startup"));
+		WMAddPopUpButtonItem(panel->sndevntP, _("WSoundServer Startup"));
+		WMAddPopUpButtonItem(panel->sndevntP, _("WSoundServer Shutdown"));
 		WMAddPopUpButtonItem(panel->sndevntP, _("Application Startup"));
 		WMAddPopUpButtonItem(panel->sndevntP, _("Application Exit"));
 		WMAddPopUpButtonItem(panel->sndevntP, _("Maximize"));
@@ -177,6 +178,10 @@ Initialize(WMScreen *scr)
 		WMAddPopUpButtonItem(panel->sndevntP, _("UnHide"));
 		WMAddPopUpButtonItem(panel->sndevntP, _("Shade"));
 		WMAddPopUpButtonItem(panel->sndevntP, _("UnShade"));
+		WMAddPopUpButtonItem(panel->sndevntP, _("Dock"));
+		WMAddPopUpButtonItem(panel->sndevntP, _("UnDock"));
+		WMAddPopUpButtonItem(panel->sndevntP, _("Kaboom"));
+
 		WMSetPopUpButtonAction(panel->sndevntP, changeSoundEvent, panel);
 		WMSetPopUpButtonSelectedItem(panel->sndevntP, 0);
 		
